@@ -38,7 +38,7 @@
 #'     projections.}
 #'   \item{converged}{A logical indicating whether the algorithm converged
 #'     or not.}
-#'   \item{nbrOfIterations}{Number of iterations completed before returning.}
+#'   \item{num_iterations}{Number of iterations completed before returning.}
 #'   \item{call}{the call that created this object; allows it to be
 #'     \code{updated()}.}
 #'
@@ -47,8 +47,11 @@
 #' @keywords regression smooth nonparametric
 #'
 #' @references
-#'   \dQuote{Principal Curves} by Hastie, T. and Stuetzle, W. 1989, JASA.
-#'   See also Banfield and Raftery (JASA, 1992).
+#'  Hastie, T. and Stuetzle, W.,
+#'  \href{https://www.jstor.org/stable/2289936}{Principal Curves},
+#'  JASA, Vol. 84, No. 406 (Jun., 1989), pp. 502-516,
+#'  DOI: \href{https://doi.org/10.2307/2289936}{10.2307/2289936}
+#'  (\href{https://web.stanford.edu/~hastie/Papers/principalcurves.pdf}{PDF}).
 #'
 #' @export
 #'
@@ -225,60 +228,6 @@ principal_curve <- function(
   out
 }
 
-#' Fit a Principal Curve
-#'
-#' This function will be deprecated on July 1st, 2018.
-#' Use \code{\link{principal_curve}} instead.
-#'
-#' @param x a matrix of points in arbitrary dimension.
-#' @param start either a previously fit principal curve, or else a matrix
-#'   of points that in row order define a starting curve. If missing or NULL,
-#'   then the first principal component is used.  If the smoother is
-#'   \code{"periodic_lowess"}, then a circle is used as the start.
-#' @param thresh convergence threshold on shortest distances to the curve.
-#' @param plot.true If \code{TRUE} the iterations are plotted.
-#' @param maxit maximum number of iterations.
-#' @param stretch a factor by which the curve can be extrapolated when
-#'   points are projected.  Default is 2 (times the last segment
-#'   length). The default is 0 for \code{smoother} equal to
-#'   \code{"periodic_lowess"}.
-#' @param smoother choice of smoother. The default is
-#'   \code{"smooth_spline"}, and other choices are \code{"lowess"} and
-#'   \code{"periodic_lowess"}. The latter allows one to fit closed curves.
-#'   Beware, you may want to use \code{iter = 0} with \code{lowess()}.
-#' @param trace If \code{TRUE}, the iteration information is printed
-#' @param ... additional arguments to the smoothers
-#'
-#' @export
-principal.curve <- function(
-  x,
-  start = NULL,
-  thresh = 0.001,
-  plot.true = FALSE,
-  maxit = 10,
-  stretch = 2,
-  smoother = c("smooth_spline", "lowess", "periodic_lowess"),
-  trace = FALSE,
-  ...
-) {
-  # This function will be deprecated on July 1st, 2018
-  # .Deprecated("principal_curve", package = "princurve", old = "principal.curve")
-
-  out <- principal_curve(
-    x = x,
-    start = start,
-    thresh = thresh,
-    maxit = maxit,
-    stretch = stretch,
-    smoother = smoother,
-    trace = trace,
-    plot_iterations = plot.true,
-    ...
-  )
-  names(out)[[2]] <- "tag"
-  out
-}
-
 #' @rdname principal_curve
 #' @export
 #' @importFrom graphics lines
@@ -314,6 +263,6 @@ points.principal_curve <- function(x, ...) {
 #' @param s a parametrized curve, represented by a polygon.
 #' @importFrom graphics segments
 #' @export
-whiskers <- function(x, s) {
-  graphics::segments(x[, 1], x[, 2], s[, 1], s[, 2])
+whiskers <- function(x, s, ...) {
+  graphics::segments(x[, 1], x[, 2], s[, 1], s[, 2], ...)
 }
